API docs for “spamfighter.interfaces.IPartnerAuthorizer”

# Class s.i.IPartnerAuthorizer(Interface):

Part of spamfighter.interfaces View Source View In Hierarchy

Модуль авторизации партнеров. Способ авторизации не задается интерфейсом, но в результате авторизации мы должны получить партнера (`IPartner`).

Method | authorize | Выполнить авторизацию партнера.

def authorize(partner_info): (source)
Выполнить авторизацию партнера.

Parameters | partner_info | информация о партнере
Returns | Deferred, партнер (`IPartner`) (type: `twisted.internet.defer.Deferred` )